/// <reference lib="es2019" />
/// <reference path="http-header-value.headers.d.ts" />
declare module "@hatsy/http-header-value/node" {
    import type { IncomingMessage } from "node:http";
    import { URL } from "node:url";
    import { HttpForwardRep, HttpForwardTrust } from "@hatsy/http-header-value/headers";
    /**
     * HTTP request addressing report.
     *
     * Collected with respect to trusted proxy forwarding information.
     */
    export interface HttpAddressRep {
        /**
         * Trusted proxy forwarding report.
         */
        readonly forward: HttpForwardRep;
        /**
         * Request URL.
         */
        readonly url: URL;
        /**
         * Remote address.
         */
        readonly ip: string;
    }
    export const HttpAddressRep: {
        /**
         * Collects {@link @hatsy/http-header-value/headers!HttpForwardRep.Defaults proxy forwarding defaults} from HTTP
         * request.
         *
         * This information does not rely on proxy forwarding information.
         *
         * @param request - HTTP request to collect information from.
         *
         * @returns Collected proxy forwarding defaults.
         */
        defaults(this: void, request: IncomingMessage): HttpForwardRep.Defaults;
        /**
         * Builds addressing report by HTTP request.
         *
         * Uses {@link @hatsy/http-header-value/headers!HttpForwardRep#by HttpForwardRep.by()} to collect trusted proxy
         * forwarding information.
         *
         * @param request - HTTP request to collect information from.
         * @param trust - A trust policy to proxy forwarding records.
         *
         * @returns  Collected HTTP request info.
         */
        by(this: void, request: IncomingMessage, trust?: HttpForwardTrust): HttpAddressRep;
    };
}
//# sourceMappingURL=http-header-value.node.d.ts.map
