import { URL } from 'node:url';
import './hthv-parse-89a10775.js';
import { H as HttpForwardRep } from './http-forward-rep-51e650c0.js';

const HttpAddressRep = {
    /**
     * Collects {@link @hatsy/http-header-value/headers!HttpForwardRep.Defaults proxy forwarding defaults} from HTTP
     * request.
     *
     * This information does not rely on proxy forwarding information.
     *
     * @param request - HTTP request to collect information from.
     *
     * @returns Collected proxy forwarding defaults.
     */
    defaults(request) {
        const { connection, headers, } = request;
        const { localAddress, localPort, remoteAddress = 'unknown' } = connection;
        return {
            by: localAddress || 'unknown',
            for: remoteAddress,
            host: headers.host
                || (localAddress ? (localPort ? `${localAddress}:${localPort}` : localAddress) : 'unknown'),
            proto: connection.encrypted ? 'https' : 'http',
        };
    },
    /**
     * Builds addressing report by HTTP request.
     *
     * Uses {@link @hatsy/http-header-value/headers!HttpForwardRep#by HttpForwardRep.by()} to collect trusted proxy
     * forwarding information.
     *
     * @param request - HTTP request to collect information from.
     * @param trust - A trust policy to proxy forwarding records.
     *
     * @returns  Collected HTTP request info.
     */
    by(request, trust) {
        const forwarded = HttpForwardRep.by(request.headers, HttpAddressRep.defaults(request), trust);
        let requestURL;
        return {
            forward: forwarded,
            ip: forwarded.for,
            get url() {
                return (requestURL
                    || (requestURL = new URL(request.url || '', `${forwarded.proto}://${forwarded.host}`)));
            },
        };
    },
};

export { HttpAddressRep };
//# sourceMappingURL=http-header-value.node.js.map
